@@ -195,7 +195,6 @@ void Example_TextView::insert_text(Glib::RefPtr<Gtk::TextBuffer>& refBuffer)
   iter = refBuffer->insert(iter, "The text widget can display text with all kinds of nifty attributes. It also supports multiple views of the same buffer; this demo is showing the same buffer in two places.\n\n");
   iter = refBuffer->insert_with_tag(iter, "Font styles. ", "heading");
   iter = refBuffer->insert(iter, "For example, you can have ");
-
   iter = refBuffer->insert_with_tag(iter, "italic", "italic");
 
   iter = refBuffer->insert(iter, ", ");
@@ -345,17 +344,17 @@ void Example_TextView::insert_text(Glib::RefPtr<Gtk::TextBuffer>& refBuffer)
   iter = refBuffer->insert(iter, "You can put widgets in the buffer: Here's a button: ");
 
   Glib::RefPtr<Gtk::TextChildAnchor> refAnchor = refBuffer->create_child_anchor(iter);
-  iter = refBuffer->insert(iter, " and a menu: ");
+  iter = refBuffer->insert(refBuffer->end(), " and a menu: ");
   refAnchor = refBuffer->create_child_anchor(iter);
-  iter = refBuffer->insert(iter, " and a scale: ");
+  iter = refBuffer->insert(refBuffer->end(), " and a scale: ");
   refAnchor = refBuffer->create_child_anchor(iter);
-  iter = refBuffer->insert(iter, " and an animation: ");
+  iter = refBuffer->insert(refBuffer->end(), " and an animation: ");
   refAnchor = refBuffer->create_child_anchor(iter);
-  iter = refBuffer->insert(iter, " finally a text entry: ");
+  iter = refBuffer->insert(refBuffer->end(), " finally a text entry: ");
   refAnchor = refBuffer->create_child_anchor(iter);
-  iter = refBuffer->insert(iter, ".\n");
+  iter = refBuffer->insert(refBuffer->end(), ".\n");
 
-  iter = refBuffer->insert(iter, "\n\nThis demo doesn't demonstrate all the GtkTextBuffer features; it leaves out, for example: invisible/hidden text (doesn't work in GTK 2, but planned), tab stops, application-drawn areas on the sides of the widget for displaying breakpoints and such...");
+  refBuffer->insert(iter, "\n\nThis demo doesn't demonstrate all the GtkTextBuffer features; it leaves out, for example: invisible/hidden text (doesn't work in GTK 2, but planned), tab stops, application-drawn areas on the sides of the widget for displaying breakpoints and such...");
 
   // Apply word_wrap tag to whole buffer
   Gtk::TextIter start, end;
@@ -365,9 +364,9 @@ void Example_TextView::insert_text(Glib::RefPtr<Gtk::TextBuffer>& refBuffer)
 
 bool Example_TextView::find_anchor(Gtk::TextIter& iter)
 {
-  while (iter.forward_char())
+  while(++iter)
   {
-    if (iter.get_child_anchor())
+    if(iter.get_child_anchor())
       return true;
   }
   return false;
@@ -379,7 +378,7 @@ void Example_TextView::attach_widgets(Gtk::TextView& text_view)
   Gtk::TextIter iter = refBuffer->begin();
 
   int i = 0;
-  while (find_anchor (iter))
+  while(find_anchor(iter))
   {
     Glib::RefPtr<Gtk::TextChildAnchor> refAnchor = iter.get_child_anchor();
     Gtk::Widget* pWidget = 0;
@@ -396,8 +395,8 @@ void Example_TextView::attach_widgets(Gtk::TextView& text_view)
       Gtk::Menu* pMenu = Gtk::manage( new Gtk::Menu() );
       MenuList items = pMenu->items();
       items.push_back(MenuElem("Option 1"));
-      items.push_back(MenuElem("Option 1"));
-      items.push_back(MenuElem("Option 1"));
+      items.push_back(MenuElem("Option 2"));
+      items.push_back(MenuElem("Option 3"));
 
       Gtk::OptionMenu* pOptionMenu = Gtk::manage( new Gtk::OptionMenu() );
       pOptionMenu->set_menu(*pMenu);
@@ -445,11 +444,11 @@ Window_EasterEgg::Window_EasterEgg()
   set_default_size(300, 400);
 
   Glib::RefPtr<Gtk::TextBuffer> refBuffer = Gtk::TextBuffer::create();
-  Gtk::TextIter iter = refBuffer->begin();
+  Gtk::TextIter iter = refBuffer->end();
 
   iter = refBuffer->insert(iter, "This buffer is shared by a set of nested text views.\n Nested view:\n");
   Glib::RefPtr<Gtk::TextChildAnchor> refAnchor = refBuffer->create_child_anchor(iter);
-  iter = refBuffer->insert(iter, "\nDon't do this in real applications, please.\n");
+  refBuffer->insert(refBuffer->end(), "\nDon't do this in real applications, please.\n");
 
   m_pTextView = Gtk::manage( new Gtk::TextView(refBuffer) );
 
