@@ -1,8 +1,7 @@
 // -*- c++ -*-
-/* $Id: object.cc,v 1.33 2002/07/07 12:16:48 murrayc Exp $ */
+/* $Id: object.cc,v 1.38 2002/12/20 20:05:38 daniel Exp $ */
 
-/* Copyright 1998-1999 The gtkmm Development Team
- * Copyright 2001      Free Software Foundation
+/* Copyright 1998-2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -29,24 +28,7 @@
 
 #include <cstdarg>
 
-#if 0 /* see Glib::Object::Object(GObject* castitem) */
 #include <cstring>
-#endif
-
-
-// XXX: Most of the text below is grossly outdated.  Don't read it.
-
-//Thoughts:
-//Q. Should Object be a shared-reference smart pointer, so that we can do this: Object object2 = object1; ?
-//A. Probably not. It would be more natural to do Object* pObject2 = pObject1 and do your own appropriate memory management.
-//   You could still use a generic shared-reference smart pointer if you like, but that should be orthogonal.
-//   e.g.  shared_ptr<Object> refObject1(...);  shared_ptr<Object> refObject2 = refObject1;
-//   We could recommend the use of boost::shared_ptr<> for this.
-
-//Thoughts:
-//Q. Can we allow a C++ Glib::Object to be destroyed?
-//A. Apparently not. The C++ wrapper needs to live as long as the underlying C instance, because the underlying instance uses our signal handlers.
-//   And we can't just allow premature destruction, because GObject has no destroy signal so users of the objects can not respond to their destruction intelligently.
 
 //Weak references:
 //I'm not sure what the point of these are apart from being a hacky way out of circular references,
@@ -217,13 +199,10 @@ Object::Object(const Glib::ConstructParams& construct_params)
 
 Object::Object(GObject* castitem)
 {
-#if 0
-  // XXX: Temporary hack:
-  // Disabled, because it causes more annoyance than good, unfortunately.
-  // Because of the early disconnection of the C++ wrapper object, it is
-  // often recreated on the fly during the destroy process.  It would be
-  // nice if we could prevent the recreation.  TODO: Think about it.
-
+  //I disabled this check because libglademm really does need to do this.
+  //(actually it tells libglade to instantiate "gtkmm_" types.
+  //The 2nd instance bug will be caught elsewhere anyway.
+/*
   static const char gtkmm_prefix[] = "gtkmm__";
   const char *const type_name = G_OBJECT_TYPE_NAME(castitem);
 
@@ -232,9 +211,12 @@ Object::Object(GObject* castitem)
     g_warning("Glib::Object::Object(GObject*): "
               "An object of type '%s' was created directly via g_object_new(). "
               "The Object::Object(const Glib::ConstructParams&) constructor "
-              "should be used instead.", type_name);
+              "should be used instead.\n"
+              "This could happen if the C instance lived longer than the C++ instance, so that "
+              "a second C++ instance was created automatically to wrap it. That would be a gtkmm bug that you should report.",
+               type_name);
   }
-#endif
+*/
 
   // Connect the GObject and Glib::Object instances.
   ObjectBase::initialize(castitem);
@@ -243,15 +225,6 @@ Object::Object(GObject* castitem)
 Object::~Object()
 {
   cpp_destruction_in_progress_ = true;
-
-  if(GObject *const object = gobject_)
-  {
-    gobject_ = 0;
-
-    // Remove the pointer to the wrapper from the underlying instance.
-    // This does _not_ cause invocation of the destroy_notify callback.
-    g_object_steal_qdata(object, quark_);
-  }
 }
 
 /*
