@@ -1,4 +1,4 @@
-/* $Id: generate_defs_gtk.cc,v 1.4 2002/02/25 15:12:25 murrayc Exp $ */
+/* $Id: generate_defs_gtk.cc,v 1.6 2002/12/31 17:56:54 daniel Exp $ */
 
 /* generate_defs_gtk.cc
  *
@@ -27,14 +27,26 @@ int main (int argc, char *argv[])
 {
   gtk_init(&argc, &argv);
 
-  std::cout << get_defs( ATK_TYPE_HYPERLINK)
-            << get_defs( ATK_TYPE_OBJECT )
-            << get_defs( ATK_TYPE_REGISTRY)
-            << get_defs( ATK_TYPE_RELATION)
-            << get_defs( ATK_TYPE_RELATION_SET)
-            << get_defs( ATK_TYPE_STATE_SET)
+  void *const g_class_atk_no_op_object = g_type_class_ref(ATK_TYPE_NO_OP_OBJECT);
 
-            << get_defs( GDK_TYPE_COLORMAP )
+  std::cout << get_defs( ATK_TYPE_HYPERLINK )
+            << get_defs( ATK_TYPE_OBJECT )
+            << get_defs( ATK_TYPE_COMPONENT )
+            << get_defs( ATK_TYPE_ACTION )
+            << get_defs( ATK_TYPE_EDITABLE_TEXT )
+            << get_defs( ATK_TYPE_IMAGE )
+            << get_defs( ATK_TYPE_SELECTION )
+            << get_defs( ATK_TYPE_TABLE )
+            << get_defs( ATK_TYPE_TEXT )
+            << get_defs( ATK_TYPE_VALUE )
+            << get_defs( ATK_TYPE_REGISTRY )
+            << get_defs( ATK_TYPE_RELATION )
+            << get_defs( ATK_TYPE_RELATION_SET )
+            << get_defs( ATK_TYPE_STATE_SET );
+
+  g_type_class_unref(g_class_atk_no_op_object);
+
+  std::cout << get_defs( GDK_TYPE_COLORMAP )
             << get_defs( GDK_TYPE_DRAG_CONTEXT )
             << get_defs( GDK_TYPE_DRAWABLE )
             << get_defs( GDK_TYPE_GC )
@@ -98,7 +110,9 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_OPTION_MENU )
             << get_defs( GTK_TYPE_PANED )
             << get_defs( GTK_TYPE_PIXMAP )
+#if !defined(_WIN32)
             << get_defs( GTK_TYPE_PLUG )
+#endif
             << get_defs( GTK_TYPE_PREVIEW )
             << get_defs( GTK_TYPE_PROGRESS )
             << get_defs( GTK_TYPE_PROGRESS_BAR )
@@ -112,7 +126,9 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_SEPARATOR )
             << get_defs( GTK_TYPE_SETTINGS )
             << get_defs( GTK_TYPE_SIZE_GROUP )
+#if !defined(_WIN32)
             << get_defs( GTK_TYPE_SOCKET )
+#endif
             << get_defs( GTK_TYPE_SPIN_BUTTON )
             << get_defs( GTK_TYPE_STATUSBAR )
             << get_defs( GTK_TYPE_STYLE )
